<?php

namespace Drupal\acquia_contenthub\EventSubscriber\EntityImport;

use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Event\EntityImportEvent;
use Drupal\editor\Entity\Editor;
use Drupal\filter\Entity\FilterFormat;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Handles FilterFormatEditor entity saves to apply related schema.
 */
class FilterFormatEditor implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaContentHubEvents::ENTITY_IMPORT_NEW][] = 'onImportNew';
    $events[AcquiaContentHubEvents::ENTITY_IMPORT_UPDATE][] = 'onImportNew';
    return $events;
  }

  /**
   * Ensures an editor exists for a filter format.
   *
   * @param \Drupal\acquia_contenthub\Event\EntityImportEvent $event
   *   The entity import event.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function onImportNew(EntityImportEvent $event): void {
    if (!\Drupal::moduleHandler()->moduleExists('editor')) {
      return;
    }
    $filter_format = $event->getEntity();
    // Early return if this isn't the class of entity we care about.
    if (!$filter_format instanceof FilterFormat) {
      return;
    }
    if (editor_load($filter_format->id())) {
      return;
    }

    $values = [
      'editor' => $this->getAvailableCkeditorPlugin(),
      'format' => $filter_format->id(),
    ];
    $editor = Editor::create($values);
    $editor->save();
  }

  /**
   * Returns an available ckeditor plugin id.
   *
   * If ckeditor5 is available return it otherwise return ckeditor.
   *
   * @return string
   *   The ckeditor plugin id.
   *
   * @todo Remove when the minimum version required is Drupal 10.
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  protected function getAvailableCkeditorPlugin(): string {
    /** @var \Drupal\editor\Plugin\EditorManager $manager */
    $manager = \Drupal::service('plugin.manager.editor');
    $ckeditor = $manager->getDefinition('ckeditor5');
    return $ckeditor ? 'ckeditor5' : 'ckeditor';
  }

}
