<?php

namespace Drupal\Tests\acquia_contenthub\Kernel\EventSubscriber\EntityImport\FilterFormat;

use Acquia\ContentHubClient\CDF\CDFObject;
use Drupal\acquia_contenthub\Event\EntityImportEvent;
use Drupal\acquia_contenthub\EventSubscriber\EntityImport\FilterFormatEditor;
use Drupal\editor\Entity\Editor;
use Drupal\filter\Entity\FilterFormat;
use Drupal\KernelTests\KernelTestBase;
use Drupal\Tests\acquia_contenthub\Kernel\Stubs\DrupalVersion;
use Symfony\Component\Yaml\Yaml;

/**
 * Tests filter format creation.
 *
 * @coversDefaultClass \Drupal\acquia_contenthub\EventSubscriber\EntityImport\FilterFormatEditor
 *
 * @group acquia_contenthub
 *
 * @requires module ckeditor
 *
 * @package Drupal\Tests\acquia_contenthub\Kernel
 */
class FilterFormatEditorTest extends KernelTestBase {

  use DrupalVersion;

  /**
   * Filter format to test.
   *
   * @var \Drupal\filter\Entity\FilterFormat
   */
  protected $filterFormat;

  /**
   * SUT.
   *
   * @var \Drupal\acquia_contenthub\EventSubscriber\EntityImport\FilterFormatEditor
   */
  protected $filterFormatEditor;

  /**
   * Ckeditor module and plugin.
   *
   * @var string
   */
  protected $ckEditor;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'editor',
    'filter',
    'system',
    'user',
  ];

  /**
   * {@inheritDoc}
   */
  public function setUp(): void {
    $this->ckEditor = $this->getCkeditorModuleName();
    static::$modules[] = $this->ckEditor;
    parent::setUp();
    $this->installEntitySchema('filter_format');
    $this->filterFormat = FilterFormat::create(
      Yaml::parseFile('core/profiles/standard/config/install/filter.format.basic_html.yml')
    );
    $this->filterFormat->save();
    $this->filterFormatEditor = new FilterFormatEditor();
  }

  /**
   * Tests that editor gets created for both ckeditor and ckeditor5 plugin.
   *
   * @covers ::onImportNew
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function testEditorCreation(): void {
    $this->assertNull(Editor::load($this->filterFormat->id()));
    $event = new EntityImportEvent($this->filterFormat, $this->prophesize(CDFObject::class)->reveal());
    $this->filterFormatEditor->onImportNew($event);
    $editor = Editor::load($this->filterFormat->id());
    $this->assertNotNull($editor);
    $this->assertEquals($this->ckEditor, $editor->getEditor());
  }

}
